Index: /branches/SHM-dev/source/Lib/TLibCommon/TComPic.cpp
===================================================================
--- /branches/SHM-dev/source/Lib/TLibCommon/TComPic.cpp	(revision 1511)
+++ /branches/SHM-dev/source/Lib/TLibCommon/TComPic.cpp	(revision 1512)
@@ -62,5 +62,5 @@
 #if SVC_EXTENSION
   memset( m_pcFullPelBaseRec, 0, sizeof( m_pcFullPelBaseRec ) );
-  memset( m_bSpatialEnhLayer, false, sizeof( m_bSpatialEnhLayer ) );
+  memset( m_requireResampling, false, sizeof( m_requireResampling ) );
   memset( m_equalPictureSizeAndOffsetFlag, false, sizeof( m_equalPictureSizeAndOffsetFlag ) );
   memset( m_mvScalingFactor, 0, sizeof( m_mvScalingFactor ) );
@@ -100,5 +100,5 @@
   for( Int i = 0; i < MAX_LAYERS; i++ )
   {
-    if( m_bSpatialEnhLayer[i] )
+    if( m_requireResampling[i] )
     {
       m_pcFullPelBaseRec[i] = new TComPicYuv;  m_pcFullPelBaseRec[i]->create( iWidth, iHeight, chromaFormatIDC, uiMaxCuWidth, uiMaxCuHeight, uiMaxDepth, true, &conformanceWindow );
@@ -158,5 +158,5 @@
   for( Int i = 0; i < MAX_LAYERS; i++ )
   {
-    if( m_bSpatialEnhLayer[i] && m_pcFullPelBaseRec[i] )
+    if( m_requireResampling[i] && m_pcFullPelBaseRec[i] )
     {
       m_pcFullPelBaseRec[i]->destroy();
Index: /branches/SHM-dev/source/Lib/TLibCommon/TComSlice.cpp
===================================================================
--- /branches/SHM-dev/source/Lib/TLibCommon/TComSlice.cpp	(revision 1511)
+++ /branches/SHM-dev/source/Lib/TLibCommon/TComSlice.cpp	(revision 1512)
@@ -3333,5 +3333,5 @@
 
       // copy scalability ratio, it is needed to get the correct location for the motion field of the corresponding reference layer block
-      pcIlpPic[refLayerIdc]->setSpatialEnhLayerFlag( refLayerIdc, m_pcPic->isSpatialEnhLayer(refLayerIdc) );
+      pcIlpPic[refLayerIdc]->setRequireResamplingFlag( refLayerIdc, m_pcPic->requireResampling(refLayerIdc) );
 
       pcIlpPic[refLayerIdc]->copyUpsampledPictureYuv( m_pcPic->getFullPelBaseRec( refLayerIdc ), pcIlpPic[refLayerIdc]->getPicYuvRec() );      
Index: /branches/SHM-dev/source/Lib/TLibDecoder/TDecTop.cpp
===================================================================
--- /branches/SHM-dev/source/Lib/TLibDecoder/TDecTop.cpp	(revision 1511)
+++ /branches/SHM-dev/source/Lib/TLibDecoder/TDecTop.cpp	(revision 1512)
@@ -272,5 +272,5 @@
     if(m_layerId > 0)
     {
-      xSetSpatialEnhLayerFlag( vps, sps, pps, rpcPic );
+      xSetRequireResamplingFlag( vps, sps, pps, rpcPic );
     }
 
@@ -321,5 +321,5 @@
   if( m_layerId > 0 )
   {
-    xSetSpatialEnhLayerFlag( vps, sps, pps, rpcPic );
+    xSetRequireResamplingFlag( vps, sps, pps, rpcPic );
   }
 
@@ -1711,5 +1711,5 @@
 #endif
 
-        if( m_pcPic->isSpatialEnhLayer(refLayerIdc) )
+        if( m_pcPic->requireResampling(refLayerIdc) )
         {
           // check for the sample prediction picture type
@@ -2590,5 +2590,5 @@
 }
 
-Void TDecTop::xSetSpatialEnhLayerFlag( const TComVPS &vps, const TComSPS &sps, const TComPPS &pps, TComPic* pic )
+Void TDecTop::xSetRequireResamplingFlag( const TComVPS &vps, const TComSPS &sps, const TComPPS &pps, TComPic* pic )
 {
   for(UInt i = 0; i < vps.getNumDirectRefLayers( m_layerId ); i++ )
@@ -2620,5 +2620,5 @@
       )
     {
-      pic->setSpatialEnhLayerFlag( i, true );
+      pic->setRequireResamplingFlag( i, true );
 
       //only for scalable extension
Index: /branches/SHM-dev/source/Lib/TLibDecoder/TDecTop.h
===================================================================
--- /branches/SHM-dev/source/Lib/TLibDecoder/TDecTop.h	(revision 1511)
+++ /branches/SHM-dev/source/Lib/TLibDecoder/TDecTop.h	(revision 1512)
@@ -262,7 +262,7 @@
 
 #if CONFORMANCE_BITSTREAM_MODE
-  std::vector<TComPic>* getConfListPic() { return &m_confListPic; }
-  Bool      getConfModeFlag() const      { return m_confModeFlag; }
-  Void      setConfModeFlag(Bool x)      { m_confModeFlag = x;    }
+  std::vector<TComPic>* getConfListPic()                                    { return &m_confListPic; }
+  Bool      getConfModeFlag() const                                         { return m_confModeFlag; }
+  Void      setConfModeFlag(Bool x)                                         { m_confModeFlag = x;    }
 #endif
 #endif //SVC_EXTENSION
@@ -279,5 +279,5 @@
 #if SVC_EXTENSION
   Bool      xDecodeSlice(InputNALUnit &nalu, Int &iSkipFrame, Int iPOCLastDisplay, UInt& curLayerId, Bool& bNewPOC);
-  Void      xSetSpatialEnhLayerFlag( const TComVPS &vps, const TComSPS &sps, const TComPPS &pps, TComPic* pic );
+  Void      xSetRequireResamplingFlag( const TComVPS &vps, const TComSPS &sps, const TComPPS &pps, TComPic* pic );
 #else
   Bool      xDecodeSlice(InputNALUnit &nalu, Int &iSkipFrame, Int iPOCLastDisplay);
Index: /branches/SHM-dev/source/Lib/TLibEncoder/TEncGOP.cpp
===================================================================
--- /branches/SHM-dev/source/Lib/TLibEncoder/TEncGOP.cpp	(revision 1511)
+++ /branches/SHM-dev/source/Lib/TLibEncoder/TEncGOP.cpp	(revision 1512)
@@ -1652,5 +1652,5 @@
           m_Enc3DAsymLUTPicUpdate.addRefLayerId( pcSlice->getVPS()->getRefLayerId(m_layerId, refLayerIdc) );
 
-          if( pcSlice->getPic()->getPosScalingFactor(refLayerIdc, 0) < POS_SCALING_FACTOR_1X || pcSlice->getPic()->getPosScalingFactor(refLayerIdc, 1) < POS_SCALING_FACTOR_1X ) //if(pcPic->isSpatialEnhLayer(refLayerIdc))
+          if( pcSlice->getPic()->getPosScalingFactor(refLayerIdc, 0) < POS_SCALING_FACTOR_1X || pcSlice->getPic()->getPosScalingFactor(refLayerIdc, 1) < POS_SCALING_FACTOR_1X ) //if(pcPic->requireResampling(refLayerIdc))
           {
             //downsampling
@@ -1681,5 +1681,5 @@
 #endif
 
-        if( pcPic->isSpatialEnhLayer(refLayerIdc) )
+        if( pcPic->requireResampling(refLayerIdc) )
         {
           // check for the sample prediction picture type
Index: /branches/SHM-dev/source/Lib/TLibEncoder/TEncTop.cpp
===================================================================
--- /branches/SHM-dev/source/Lib/TLibEncoder/TEncTop.cpp	(revision 1511)
+++ /branches/SHM-dev/source/Lib/TLibEncoder/TEncTop.cpp	(revision 1512)
@@ -741,5 +741,5 @@
             )
           {
-            pcEPic->setSpatialEnhLayerFlag( i, true );
+            pcEPic->setRequireResamplingFlag( i, true );
 
             //only for scalable extension
@@ -786,5 +786,5 @@
             )
           {
-            rpcPic->setSpatialEnhLayerFlag( i, true );
+            rpcPic->setRequireResamplingFlag( i, true );
 
             //only for scalable extension

Index: /branches/SHM-dev/source/Lib/TLibCommon/TComPic.h
===================================================================
--- /branches/SHM-dev/source/Lib/TLibCommon/TComPic.h	(revision 1511)
+++ /branches/SHM-dev/source/Lib/TLibCommon/TComPic.h	(revision 1512)
@@ -86,6 +86,6 @@
 
 #if SVC_EXTENSION
-  UInt                  m_layerId;              //  Layer ID
-  Bool                  m_bSpatialEnhLayer[MAX_LAYERS];       // whether current layer is a spatial enhancement layer,
+  UInt                  m_layerId;                         //  Layer ID
+  Bool                  m_requireResampling[MAX_LAYERS];   // whether current layer requires resampling
   TComPicYuv*           m_pcFullPelBaseRec[MAX_LAYERS];    // upsampled base layer recontruction for difference domain inter prediction
   Bool                  m_equalPictureSizeAndOffsetFlag[MAX_LAYERS];
@@ -192,6 +192,6 @@
   UInt          getLayerId() const                                          { return m_layerId;                                          }
   UInt          getLayerIdx() const                                         { return m_picSym.getSlice(0)->getVPS()->getLayerIdxInVps(m_layerId);     }
-  Bool          isSpatialEnhLayer(UInt refLayerIdc) const                   { return m_bSpatialEnhLayer[refLayerIdc];                    }
-  Void          setSpatialEnhLayerFlag (UInt refLayerIdc, Bool b)           { m_bSpatialEnhLayer[refLayerIdc] = b;                       }
+  Bool          requireResampling(UInt refLayerIdc) const                   { return m_requireResampling[refLayerIdc];                   }
+  Void          setRequireResamplingFlag (UInt refLayerIdc, Bool b)         { m_requireResampling[refLayerIdc] = b;                      }
   Void          setFullPelBaseRec   (UInt refLayerIdc, TComPicYuv* p)       { m_pcFullPelBaseRec[refLayerIdc] = p;                       }
   TComPicYuv*   getFullPelBaseRec   (UInt refLayerIdc) const                { return  m_pcFullPelBaseRec[refLayerIdc];                   }